about summary refs log tree commit diff
path: root/web/atom-feed
diff options
context:
space:
mode:
authorVincent Ambo <mail@tazj.in>2021-11-04T14·39+0100
committertazjin <mail@tazj.in>2021-11-04T15·57+0000
commitf360bbdcf0328839da963daea845eef61d7cb395 (patch)
tree4457036e3c13a3a41ac4a047201f38610454b932 /web/atom-feed
parent00ae396eeb0f6962a8a4bff21ec8ee039c0abaf7 (diff)
refactor(web/blog): Move atom feed creation logic to //web/blog r/3000
This was previously all inside of my personal homepage configuration,
but that's not really where it belongs.

This moves the blog post -> feed entry logic to //web/blog and moves
some other minor logic (like entry order) into the atom feed
implementation itself.

Change-Id: Idde0241c48e979580de73f2b9afd04e6ca7f4c9a
Reviewed-on: https://cl.tvl.fyi/c/depot/+/3770
Tested-by: BuildkiteCI
Reviewed-by: sterni <sternenseemann@systemli.org>
Diffstat (limited to 'web/atom-feed')
-rw-r--r--web/atom-feed/default.nix19
1 files changed, 13 insertions, 6 deletions
diff --git a/web/atom-feed/default.nix b/web/atom-feed/default.nix
index 9ed2c61892..1fbcde9bd4 100644
--- a/web/atom-feed/default.nix
+++ b/web/atom-feed/default.nix
@@ -5,8 +5,8 @@
 with depot.nix.yants;
 
 let
-  inherit (builtins) map readFile replaceStrings;
-  inherit (lib) concatStrings concatStringsSep removeSuffix;
+  inherit (builtins) foldl' map readFile replaceStrings sort;
+  inherit (lib) concatStrings concatStringsSep max removeSuffix;
   inherit (pkgs) runCommandNoCC;
 
   # 'link' describes a related link to a feed, or feed element.
@@ -67,8 +67,9 @@ let
     title = string;
 
     # Indicates the last time the feed was modified in a significant
-    # way (in seconds since epoch). Recommended element.
-    updated = int;
+    # way (in seconds since epoch). Will be calculated based on most
+    # recently updated entry if unset.
+    updated = option int;
 
     # Entries contained within the feed.
     entries = list entry;
@@ -127,17 +128,23 @@ let
     </entry>
   '');
 
+  mostRecentlyUpdated = defun [ (list entry) int ] (entries:
+    foldl' max 0 (map (e: e.updated) entries)
+  );
+
+  sortEntries = sort (a: b: a.published > b.published);
+
   renderFeed = defun [ feed string ] (f: ''
     <?xml version="1.0" encoding="utf-8"?>
     <feed xmlns="http://www.w3.org/2005/Atom">
       ${elem "id" f.id}
       ${elem "title" f.title}
-      ${elem "updated" (renderEpoch f.updated)}
+      ${elem "updated" (renderEpoch (f.updated or (mostRecentlyUpdated f.entries)))}
       ${concatStringsSep "\n" (map renderAuthor (f.authors or []))}
       ${if f ? subtitle then elem "subtitle" f.subtitle else ""}
       ${if f ? rights then elem "rights" f.rights else ""}
       ${concatStrings (map renderLink (f.links or []))}
-      ${concatStrings (map renderEntry f.entries)}
+      ${concatStrings (map renderEntry (sortEntries f.entries))}
     </feed>
   '');
 in {